#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location    : http://www.amule.org/
# last revised       : 21.12.2011

softnamesrc='aMule'
softname='amule'
softversion='2.3.1'
packageversion='72.1'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softnamesrc-$softversion.tar.bz2"
src="$buildir/$softnamesrc-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://mesh.dl.sourceforge.net/sourceforge/amule/$softnamesrc-$softversion.tar.bz2

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
amule: amule - P2P software
amule:
amule: aMule is an eMule-like client for the eD2k and Kademlia
amule: networks, supporting multiple platforms.
amule: 
amule: 
amule: 
amule:
amule: 
amule:
amule: 
EOF

# check if source is present
if [ -f $softnamesrc-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code 
cd $buildir
tar xvjf $srcpkg
cd $src

# building

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    ./configure \
      --prefix=$prefix \
      --sysconfdir=/etc \
      --localstatedir=/var/lib \
      --mandir=/usr/man \
      --disable-debug \
      --enable-optimize \
      --enable-amule-daemon \
      --enable-amulecmd \
      --enable-webserver \
      --enable-cas \
      --enable-wxcas \
      --enable-alc \
      --enable-alcc \
      --enable-amule-gui \
      --enable-geoip \
      --enable-upnp
      
    make 
    make install DESTDIR=$dest

# add 'default' files
    mkdir -p $dest/usr/doc/$softname-$softversion
    mv $dest/usr/share/doc/$softnamesrc-$softversion/*.* $dest/usr/doc/$softname-$softversion
    rm -r $dest/usr/share/doc/
    
    cd $src/docs
    cp -a \
      ABOUT-NLS AUTHORS COPYING Changelog INSTALL README TODO\
      $dest/usr/doc/$softname-$softversion

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man page
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# erase .desktop that Amule created
rm $dest/usr/share/applications/$softname.desktop
rm $dest/usr/share/applications/alc.desktop
rm $dest/usr/share/applications/wxcas.desktop

# make .desktop
if [ ! -f $dest/usr/share/applications/$softname.desktop ]; then
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Amule
Comment=P2P utility
Exec=amule
Icon=amule
Categories=Application;Network;
Terminal=false
Type=Application
Encoding=UTF-8
EOF
fi

if [ ! -f $dest/usr/share/applications/alc.desktop ]; then
cat << "EOF" > $dest/usr/share/applications/alc.desktop
[Desktop Entry]
Name=aLinkCreator
Comment=aMule ed2k link creator
Exec=alc
Icon=alc
Categories=Application;Network;
Terminal=false
Type=Application
Encoding=UTF-8
EOF
fi

if [ ! -f $dest/usr/share/applications/wxcas.desktop ]; then
cat << "EOF" > $dest/usr/share/applications/wxcas.desktop
[Desktop Entry]
Name=wxCas
Comment=aMule online statistics
Exec=wxcas
Icon=wxcas
Categories=Application;Network;
Terminal=false
Type=Application
Encoding=UTF-8
EOF
fi

# free desktop complaint
cd $src
cp ../$softname.png $dest/usr/share/icons/hicolor/48x48/apps/$softname.png
cp ../alc.png $dest/usr/share/icons/hicolor/48x48/apps/alc.png
cp ../wxcas.png $dest/usr/share/icons/hicolor/48x48/apps/wxcas.png

rm -r $dest/usr/share/pixmaps/

# put the ZenWalk build in the right directory
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# .md5
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/amule/source/build-amule.sh > $package.src
echo $source >> $package.src

# erase source
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
